==> jena-4.6.0-source-release.zip: jena-4.6.0/jena-fuseki2/jena-fuseki-ui/tests/unit/components/serverstatus.vue.spec.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { expect } from 'chai'
import { createLocalVue, shallowMount } from '@vue/test-utils'
import ServerStatus from '@/components/ServerStatus.vue'
import ServerStatusModel from '@/model/server.status'
import sinon from 'sinon'

const localVue = createLocalVue()

let count = 0

localVue.prototype.$fusekiService = {
  async getServerStatus () {
    count += 1
    return new ServerStatusModel(true, `OK ${count}`)
  }
}

describe('ServerStatus', () => {
  let fakeClock
  let component
  const mountFunction = options => {
    return shallowMount(ServerStatus, {
      localVue,
      ...options
    })
  }
  beforeEach(async () => {
    count = 0
    fakeClock = sinon.useFakeTimers()
    component = mountFunction()
  })
  afterEach(() => {
    fakeClock.restore()
  })
  it('returns the correct server status', async () => {
    expect(component.vm.serverStatusText).to.equal('OK 1')
  })
  it('returns the correct server status in the interval too', async () => {
    await fakeClock.tickAsync(5000)
    expect(component.vm.serverStatusText).to.equal('OK 2')
  })
  it('destroys the interval', async () => {
    expect(component.vm.interval).to.not.equal(null)
    component.vm.$destroy()
    expect(component.vm.interval).to.equal(null)
  })
})

==> jena-4.7.0-source-release.zip: jena-4.7.0/jena-fuseki2/jena-fuseki-ui/tests/unit/components/serverstatus.vue.spec.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { expect } from 'chai'
import { mount } from '@vue/test-utils'
import ServerStatus from '@/components/ServerStatus.vue'
import ServerStatusModel from '@/model/server.status'
import sinon from 'sinon'

let count = 0

describe('ServerStatus', () => {
  let fakeClock
  let component
  const mountFunction = options => {
    const mountOptions = Object.assign(options || {}, {
      shallow: true,
      global: {
        mocks: {
          $fusekiService: {
            async getServerStatus () {
              console.log('Hola!')
              count += 1
              return new ServerStatusModel(true, `OK ${count}`)
            }
          }
        }
      }
    })
    return mount(ServerStatus, {
      ...mountOptions
    })
  }
  beforeEach(async () => {
    count = 0
    fakeClock = sinon.useFakeTimers()
    component = mountFunction()
  })
  afterEach(() => {
    fakeClock.restore()
  })
  it('returns the correct server status', async () => {
    expect(component.vm.serverStatusText).to.equal('OK 1')
  })
  it('returns the correct server status in the interval too', async () => {
    await fakeClock.tickAsync(5000)
    expect(component.vm.serverStatusText).to.equal('OK 2')
  })
  it('destroys the interval', async () => {
    expect(component.vm.interval).to.not.equal(null)
    component.unmount()
    expect(component.vm.interval).to.equal(null)
  })
})
